@@ -8,14 +8,13 @@ from typing import Union, Iterable, Optional, Tuple, Dict, TypeVar, Type, Sequen
 
 import numpy as np
 import pandas as pd
-from scipy.signal import resample
 
 from nilspodlib.calibration_utils import (
     find_closest_calibration_to_date,
     find_calibrations_for_sensor,
     load_and_check_cal_info,
 )
-from nilspodlib.consts import SENSOR_SAMPLE_LENGTH
+from nilspodlib.consts import SENSOR_SAMPLE_LENGTH, GRAV
 from nilspodlib.datastream import Datastream
 from nilspodlib.exceptions import (
     InvalidInputFileError,
@@ -161,9 +160,20 @@ class Dataset:  # noqa: too-many-public-methods
         """
         self.counter = counter
         self.info = info
+
+        calibration_dict = {
+            "acc": self._factory_calibrate_acc,
+            "gyro": self._factory_calibrate_gyro,
+            "baro": self._factory_calibrate_baro,
+            "temperature": self._factory_calibrate_temperature,
+        }
+
         for k, v in sensor_data.items():
-            v = Datastream(v, self.info.sampling_rate_hz, sensor_type=k)
-            setattr(self, k, v)
+            ds = Datastream(v, self.info.sampling_rate_hz, sensor_type=k)
+            # Apply factory calibration:
+            if k in calibration_dict:
+                ds = calibration_dict[k](ds)
+            setattr(self, k, ds)
 
     @classmethod
     def from_bin_file(cls: Type[T], path: path_t, legacy_support: str = "error") -> T:
@@ -240,131 +250,58 @@ class Dataset:  # noqa: too-many-public-methods
         check = [self._check_calibration(s.acc, "acc"), self._check_calibration(s.gyro, "gyro")]
         if all(check):
             calibration = load_and_check_cal_info(calibration)
-            acc, gyro = calibration.calibrate(s.acc.data, s.gyro.data)
+            acc, gyro = calibration.calibrate(s.acc.data, s.gyro.data, acc_unit=s.acc.unit, gyr_unit=s.gyro.unit)
             s.acc.data = acc
             s.gyro.data = gyro
             s.acc.is_calibrated = True
-            s.acc._unit = calibration.acc_unit
+            s.acc.calibrated_unit = calibration.acc_unit
             s.gyro.is_calibrated = True
-            s.gyro._unit = calibration.gyro_unit
+            s.gyro.calibrated_unit = calibration.gyr_unit
         return s
 
-    def calibrate_acc(self: T, calibration: Union["CalibrationInfo", path_t], inplace: bool = False) -> T:
-        """Apply a calibration to the Acc datastream.
-
-        The final units of the datastream will depend on the used calibration values, but must likely they will be "g"
-        for Acc.
-
-        Parameters
-        ----------
-        calibration :
-            calibration object or path to .json file, that can be used to create one.
-        inplace :
-            If True this methods modifies the current dataset object. If False, a copy of the dataset and all
-            datastream objects is created
-
-        """
-        s = inplace_or_copy(self, inplace)
-        if self._check_calibration(s.acc, "acc") is True:
-            calibration = load_and_check_cal_info(calibration)
-            acc = calibration.calibrate_acc(s.acc.data)
-            s.acc.data = acc
-            s.acc.is_calibrated = True
-            s.acc._unit = calibration.acc_unit
-        return s
-
-    def calibrate_gyro(self: T, calibration: Union["CalibrationInfo", path_t], inplace: bool = False) -> T:
-        """Apply a calibration to the Gyro datastream.
-
-        The final units of the datastreams will depend on the used calibration values, but must likely they will be
-        "dps" (degrees per second) for the Gyro.
-
-        Parameters
-        ----------
-        calibration :
-            calibration object or path to .json file, that can be used to create one.
-        inplace :
-            If True this methods modifies the current dataset object. If False, a copy of the dataset and all
-            datastream objects is created
-
-        """
-        s = inplace_or_copy(self, inplace)
-        if self._check_calibration(s.gyro, "gyro") is True:
-            calibration = load_and_check_cal_info(calibration)
-            gyro = calibration.calibrate_gyro(s.gyro.data)
-            s.gyro.data = gyro
-            s.gyro.is_calibrated = True
-            s.gyro._unit = calibration.gyro_unit
-        return s
-
-    def factory_calibrate_imu(self: T, inplace: bool = False) -> T:
-        """Apply a calibration to the Acc and Gyro datastreams.
-
-        The values used for that are taken from the datasheet of the sensor_type and are likely not to be accurate.
-        For any tasks requiring precise sensor_type outputs, `calibrate_imu` should be used with measured calibration
-        values.
-
-        The final units of the output will be "g" for the Acc and "dps" (degrees per second) for the Gyro.
-
-        Parameters
-        ----------
-        inplace :
-            If True this methods modifies the current dataset object. If False, a copy of the dataset and all
-            datastream objects is created
-            Notes:
-            This just combines `factory_calibrate_acc` and `factory_calibrate_gyro`.
-
-        """
-        s = self.factory_calibrate_acc(inplace=inplace)
-        s = s.factory_calibrate_gyro(inplace=True)
-
-        return s
-
-    def factory_calibrate_gyro(self: T, inplace: bool = False) -> T:
+    def _factory_calibrate_gyro(self, gyro: Datastream) -> Datastream:
         """Apply a factory calibration to the Gyro datastream.
 
         The values used for that are taken from the datasheet of the sensor_type and are likely not to be accurate.
         For any tasks requiring precise sensor_type outputs, `calibrate_gyro` should be used with measured calibration
         values.
 
-        The final units of the output will be "dps" (degrees per second) for the Gyro.
+        The final units of the output will be "deg/s" (degrees per second) for the Gyro.
 
         Parameters
         ----------
-        inplace :
-            If True this methods modifies the current dataset object. If False, a copy of the dataset and all
-            datastream objects is created
+        gyro :
+            The uncalibrated gyro Datastream
 
         """
-        s = inplace_or_copy(self, inplace)
-        if self._check_calibration(s.gyro, "gyro") is True:
-            s.gyro.data /= 2 ** 16 / self.info.gyro_range_dps / 2
-            s.gyro.is_calibrated = True
-        return s
+        assert gyro.sensor_type == "gyro"
+        if self._check_calibration(gyro, "gyro", factory=True) is True:
+            gyro.data /= 2 ** 16 / self.info.gyro_range_dps / 2
+            gyro.is_factory_calibrated = True
+        return gyro
 
-    def factory_calibrate_acc(self: T, inplace: bool = False) -> T:
+    def _factory_calibrate_acc(self, acc: Datastream) -> Datastream:
         """Apply a factory calibration to the Acc datastream.
 
         The values used for that are taken from the datasheet of the sensor_type and are likely not to be accurate.
         For any tasks requiring precise sensor_type outputs, `calibrate_acc` should be used with measured calibration
         values.
 
-        The final units of the output will be "g" for the Acc.
+        The final units of the output will be "m/s^2" for the Acc.
 
         Parameters
         ----------
-        inplace :
-            If True this methods modifies the current dataset object. If False, a copy of the dataset and all
-            datastream objects is created
+        acc :
+            The uncalibrated acc Datastream
 
         """
-        s = inplace_or_copy(self, inplace)
-        if self._check_calibration(s.acc, "acc") is True:
-            s.acc.data /= 2 ** 16 / self.info.acc_range_g / 2
-            s.acc.is_calibrated = True
-        return s
+        assert acc.sensor_type == "acc"
+        if self._check_calibration(acc, "acc", factory=True) is True:
+            acc.data /= 2 ** 16 / self.info.acc_range_g / 2 / GRAV
+            acc.is_factory_calibrated = True
+        return acc
 
-    def factory_calibrate_baro(self: T, inplace: bool = False) -> T:
+    def _factory_calibrate_baro(self, baro: Datastream) -> Datastream:
         """Apply a calibration to the Baro datastream.
 
         The values used for that are taken from the datasheet of the sensor_type and are likely not to be accurate.
@@ -375,18 +312,17 @@ class Dataset:  # noqa: too-many-public-methods
 
         Parameters
         ----------
-        inplace :
-            If True this methods modifies the current dataset object. If False, a copy of the dataset and all
-            datastream objects is created
+        baro :
+            The uncalibrated baro Datastream
 
         """
-        s = inplace_or_copy(self, inplace)
-        if self._check_calibration(s.baro, "baro") is True:
-            s.baro.data = (s.baro.data + 101325) / 100.0
-            s.baro.is_calibrated = True
-        return s
+        assert baro.sensor_type == "baro"
+        if self._check_calibration(baro, "baro", factory=True) is True:
+            baro.data = (baro.data + 101325) / 100.0
+            baro.is_factory_calibrated = True
+        return baro
 
-    def factory_calibrate_temperature(self: Type[T], inplace: bool = False):
+    def _factory_calibrate_temperature(self, temperature: Datastream) -> Datastream:
         """Apply a factory calibration to the temperature datastream.
 
         The values used for that are taken from the datasheet of the sensor_type
@@ -395,19 +331,19 @@ class Dataset:  # noqa: too-many-public-methods
 
         Parameters
         ----------
-        inplace :
-            If True this methods modifies the current dataset object. If False, a copy of the dataset and all
-            datastream objects is created
+        temperature :
+            The uncalibrated baro temperature
+
 
         """
-        s = inplace_or_copy(self, inplace)
-        if self._check_calibration(s.temperature, "temperature") is True:
-            s.temperature.data = s.temperature.data * (2 ** -9) + 23
-            s.temperature.is_calibrated = True
-        return s
+        assert temperature.sensor_type == "temperature"
+        if self._check_calibration(temperature, "temperature", factory=True) is True:
+            temperature.data = temperature.data * (2 ** -9) + 23
+            temperature.is_factory_calibrated = True
+        return temperature
 
     @staticmethod
-    def _check_calibration(ds: Optional[Datastream], name: str):
+    def _check_calibration(ds: Optional[Datastream], name: str, factory: bool = False):
         """Check if a specific datastream is already marked as calibrated, or if the datastream does not exist.
 
         In case the datastream is already calibrated a `RepeatedCalibrationError` is raised.
@@ -419,12 +355,19 @@ class Dataset:  # noqa: too-many-public-methods
             datastream object or None
         name :
             name of the datastream object. Used to provide additional info in error messages.
-        ds: Optional[Datastream] :
+        factory :
+            If we want to check for factory calibration or not.
+            If True, it will only be checked if the dataset is factory calibrated.
+            If False, it will be checked if the dataset is normally calibrated.
 
         """
         if ds is not None:
-            if ds.is_calibrated is True:
-                raise RepeatedCalibrationError(name)
+            if factory is True:
+                check_val = ds.is_factory_calibrated
+            else:
+                check_val = ds.is_calibrated
+            if check_val is True:
+                raise RepeatedCalibrationError(name, factory)
             return True
         datastream_does_not_exist_warning(name, "calibration")
         return False
@@ -450,6 +393,8 @@ class Dataset:  # noqa: too-many-public-methods
             datastream objects is created
 
         """
+        from scipy.signal import resample  # noqa: import-outside-toplevel
+
         s = inplace_or_copy(self, inplace)
         for key, val in s.datastreams:
             setattr(s, key, val.downsample(factor))
